package com.dgtly.system.mapper;

import com.dgtly.system.domain.OrderTucEarlyWarning;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 预警业绩进度指标Mapper接口
 * 
 * @author njs
 * @date 2024-02-04
 */
public interface OrderTucEarlyWarningMapper 
{
    /**
     * 查询预警业绩进度指标
     * 
     * @param earlyId 预警业绩进度指标ID
     * @return 预警业绩进度指标
     */
    public OrderTucEarlyWarning selectOrderTucEarlyWarningById(Long earlyId);

    /**
     * 查询预警业绩进度指标列表
     * 
     * @param orderTucEarlyWarning 预警业绩进度指标
     * @return 预警业绩进度指标集合
     */
    public List<OrderTucEarlyWarning> selectOrderTucEarlyWarningList(OrderTucEarlyWarning orderTucEarlyWarning);

    /**
     * 新增预警业绩进度指标
     * 
     * @param orderTucEarlyWarning 预警业绩进度指标
     * @return 结果
     */
    public int insertOrderTucEarlyWarning(OrderTucEarlyWarning orderTucEarlyWarning);

    public int batchInsert(@Param("list") List<OrderTucEarlyWarning> list);

    /**
     * 修改预警业绩进度指标
     * 
     * @param orderTucEarlyWarning 预警业绩进度指标
     * @return 结果
     */
    public int updateOrderTucEarlyWarning(OrderTucEarlyWarning orderTucEarlyWarning);

    /**
     * 删除预警业绩进度指标
     * 
     * @param earlyId 预警业绩进度指标ID
     * @return 结果
     */
    public int deleteOrderTucEarlyWarningById(Long earlyId);

    /**
     * 批量删除预警业绩进度指标
     * 
     * @param earlyIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteOrderTucEarlyWarningByIds(String[] earlyIds);

    /**
     * @description:
     * @param:
     * @return:
     * @author: njs
     * @date: 2024/2/4 9:48
     */
    public OrderTucEarlyWarning selectOrderTucEarlyWarning(@Param("orgCode") String orgCode);

    /**
     * @description: TUC业绩指标
     * @param: [startTime, endTime]
     * @return: java.util.List<com.dgtly.system.domain.OrderTucEarlyWarning>
     * @author: njs     
     * @date: 2024/2/4 14:57
     */
    public List<OrderTucEarlyWarning> selectTucGroupSales(@Param("startTime") String startTime,@Param("endTime") String endTime);

    int deleteOrderTucEarlyWarning();
}
